@@ -1,5 +1,5 @@
 # Copyright (C) 2013 Steven Myint
-
+#
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
 # "Software"), to deal in the Software without restriction, including
@@ -8,16 +8,17 @@
 # permit persons to whom the Software is furnished to do so, subject to
 # the following conditions:
 #
-# The above copyright notice and this permission notice shall be included
-# in all copies or substantial portions of the Software.
+# The above copyright notice and this permission notice shall be
+# included in all copies or substantial portions of the Software.
 #
 # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 # EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
-# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
-# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
-# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
+# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
+# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
 
 """Modifies strings to all use the same quote where possible."""
 
@@ -28,8 +29,10 @@ import io
 import os
 import tokenize
 
+import untokenize
 
-__version__ = '0.1.5'
+
+__version__ = '0.2'
 
 
 try:
@@ -51,50 +54,23 @@ def _format_code(source, preferred_quote):
     if not source:
         return source
 
+    modified_tokens = []
+
     sio = io.StringIO(source)
-    formatted = ''
-    previous_line = ''
-    last_row = 0
-    last_column = -1
-    last_non_whitespace_token_type = None
-    for token in tokenize.generate_tokens(sio.readline):
-        token_type = token[0]
-        token_string = token[1]
-        start_row, start_column = token[2]
-        end_row, end_column = token[3]
-        line = token[4]
-
-        # Preserve escaped newlines
-        if (
-            last_non_whitespace_token_type != tokenize.COMMENT and
-            start_row > last_row and
-            (previous_line.endswith('\\\n') or
-             previous_line.endswith('\\\r\n') or
-             previous_line.endswith('\\\r'))
-        ):
-            formatted += previous_line[len(previous_line.rstrip(' \t\n\r\\')):]
-
-        # Preserve spacing
-        if start_row > last_row:
-            last_column = 0
-        if start_column > last_column:
-            formatted += line[last_column:start_column]
+    for (token_type,
+         token_string,
+         start,
+         end,
+         line) in tokenize.generate_tokens(sio.readline):
 
         if (token_type == tokenize.STRING):
-            formatted += unify_quotes(token_string,
-                                      preferred_quote=preferred_quote)
-        else:
-            formatted += token_string
+            token_string = unify_quotes(token_string,
+                                        preferred_quote=preferred_quote)
 
-        previous_line = line
+        modified_tokens.append(
+            (token_type, token_string, start, end, line))
 
-        last_row = end_row
-        last_column = end_column
-
-        if token_type not in [tokenize.INDENT, tokenize.NEWLINE, tokenize.NL]:
-            last_non_whitespace_token_type = token_type
-
-    return formatted
+    return untokenize.untokenize(modified_tokens)
 
 
 def unify_quotes(token_string, preferred_quote):
